#
# spec file for package ibus-anthy
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-anthy
BuildRequires:  anthy-devel
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject2-devel
BuildRequires:  swig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(ibus-1.0) >= 1.4.99
BuildRequires:  pkgconfig(python3)
Version:        1.5.10
Release:        1.51
Summary:        The Anthy engine for IBus input platform
License:        GPL-2.0-or-later
Group:          System/I18n/Japanese
Url:            https://github.com/ibus/ibus-anthy
Source:         https://github.com/ibus/ibus-anthy/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The Anthy engine for IBus platform. It provides Japanese input method from
libanthy.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}

%description devel
The %{name}-devel package includes the header files for the %{name} package.


%prep
%setup -q

%build
%configure --disable-static \
           --libexecdir=%{_libexecdir} \
           --with-python=python3

make %{?_smp_mflags}

%install
%makeinstall

find %{buildroot} -name "*.la" -type f -delete -print

%find_lang %{name}
%fdupes -s %{buildroot}

%suse_update_desktop_file ibus-setup-anthy System Utility settings

%post
/sbin/ldconfig
%if 0%{?suse_version} < 1330
%desktop_database_post
%icon_theme_cache_post
%endif

%postun
/sbin/ldconfig
%if 0%{?suse_version} < 1330
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS README
%license COPYING
%{_libexecdir}/ibus-*
%{_datadir}/ibus-anthy
%{_datadir}/ibus
%{_libdir}/girepository-1.0
%{_datadir}/applications/ibus-setup-anthy.desktop
%{_datadir}/icons/hicolor/
%{_libdir}/libanthygobject-*.so.*
%dir %{_datadir}/appdata/
%{_datadir}/appdata/*
%{_datadir}/glib-2.0/schemas/org.freedesktop.ibus.engine.anthy.gschema.xml

%files devel
%defattr(-,root,root,-)
%{_includedir}/ibus-anthy-1.0
%{_datadir}/gir-1.0
%{_libdir}/libanthygobject-*.so

%changelog
* Fri Sep 20 2019 qzhao@suse.com
- update ibus-anthy.spec: update to depending anthy-devel, make it
  can build successful in SLE15(openSUSE-leap-15).
* Mon Apr  2 2018 hillwood@opensuse.org
- Update version to 1.5.10
  * Fixed a warning in ibus-anthy.appdata.xml
  * Fix page_up, page_down, candidate_clicked
  * Fixed circle_typing_method for Alt-Romaji, Ctrl-/
  * Added Shift-F7 shortcut key to convert all to Katakana
  * tests: Add automation testing
  * Migrated DConf to GSettings
  * Added ISSUE_TEMPLATE
  * Updated emoji dictionary
  * Added po/es.po po/cs.po
- Switch to python3.
* Sun May 21 2017 ftake@geeko.jp
- update to 1.5.9
  * Renamed anthy.appdata.xml to ibus-anthy.appdata.xml
    and update information
  * Fixed environment variables in anthy.xml and scripts (#4)
  * Fixed __cmd_predict()
  * Enabled to click candidate and page up/down on Emoji lookup table
  * Updated Emoji dictionary for Unicode 9.0 and Emoji 3.0
- update to 1.5.8
  * Updated URL in anthy.appdata.xml.in
  * Fixed bytes to str in thumb.py for python3
  * Fixed get_xkb_layout in thumb.py
  * setup: Delete a check button "Show input mode icon"
  * Implement "Automatically commit" with periods
  * Updated emoji.t
  * Fixed PyGIWarning: GdkX11 was imported without specifying a version
  * Added Variation Sector in emoji.t
  * Split emoji.t into emoji-each.t and emoji-emoji.t
* Thu Oct  1 2015 ftake@geeko.jp
- fix no desktop DB update and icon theme cache update
* Tue Sep 22 2015 ftake@geeko.jp
- Stop providing locale(ja)
  * Most of ja locale users do not need this anymore
- Update the upstream URL
* Sat Jul 25 2015 ftake@geeko.jp
- update to 1.5.7
  * Fixed no parent when click on shortcut keys
  * Updated emoji table
  * Added textdomain in default.xml
  * Added anthy.appdata.xml
  * Fixed to import sys
  * Added icon_prop_key support for IBus 1.5.11
* Sun Sep 28 2014 ftake@geeko.jp
-update to 1.5.6
  * Remove references to deprecated GTK classes
  * Replace FileNotFoundError with IOError for Python 2
    (Fix bnc#898849)
  * Change fequencies of symbols from 500 to 0
  * Add emojis to the dictionary
  * Set preview_lines to -1 for zip code
  * Add search entry in the view dictionary dialog
* Thu Mar 20 2014 hillwood@linuxfans.org
- update to 1.5.5
  * Fixed IOError in print sys.stderr when the parent process exits.
  * Added python3 (not enabled for this package).
  * Launched an error dialog when .anthy/last-record2_default.utf8 is broken.
  * Enabled python3 in data/zipcode-textdic.py
* Mon Feb 17 2014 fcrozat@suse.com
- Move libanthygobject-1.0.so.5 to main package, devel package
  shouldn't be required by main package.
* Tue Oct  8 2013 hillwood@linuxfans.org
- update to 1.5.4
  * Removed g_type_init() calls.
  * Fixed ibus-engine-anthy --xml without display
  * Fixed kana_voiced_consonant_no_rule for 'bo'.
  * Fixed dicts.
  * Updated symbol.t with Seiza.
  * Added Era dict.
  * Updated source files with the latest GPL 2.0.
  * Imported anthy zipcode.t into ibus-anthy.
  * Added to check the input purpose for gnome-shell password dialog.
  * Implemented ISO 14755 with Ctrl+Shift+u in LATIN mode.
  * Extracted prefix in ANTHY_ZIPCODE_FILE for sh test.
* Mon Jul  8 2013 hillwood@linuxfans.org
- update to 1.5.3
  * Fixed some bugs
* Tue Jan 22 2013 hillwood@linuxfans.org
- update to 1.5.0
  * Added ibus menu customization.
  * Added us layout table for Kana.
  * Added keyboard layout customization.
  * Enabled IBusProperty.symbol with ibus 1.5 .
  * Add a .desktop file for ibus-setup-anthy
  * Updated configure.ac to use ibus pygobject3.
  * Converted pygtk2 to gir gtk3.
  * Added to sync the user config xml between versions.
  * Updated translations.
  * Added ibus menu customization.
  * Replaced the legacy icon gtk-preferences with preferences-desktop.
  * Added el.po.
  * Fixed to delete arch depended lines. (#884031)
* Fri Dec 14 2012 hillwood@linuxfans.org
- update to 1.4.99.20121006.
  * Fixed GtkBuilder bindtextdomain in ibus-setup.
  * Updated configure.ac to use ibus pygobject3.
  * Fixed MBCS dict file names (#1479)
  * Add a .desktop file for ibus-setup-anthy
  * Added IBUS_VERSION_TEST to make sure the latest ibus is used.
  * First round of string fixes.
  * Added anthy themed icon.
  * Used ibus_config_get_values
  * Added old repeated chars in symbol.t and oldchar.t
  * Fixed IBus.Bus.get_config is null. (#848023)
  * Fixed GLib.Variant.dup_strv for pygobject3 3.3.4 or later. (#854161)
  * Fixed a UI string; katakana. (#1508)
  * Enabled IBusProperty.symbol with ibus 1.5 .
  * Fixed IBus.LookupTable->candidates->len > 0 (#860135)
  * Added keyboard layout customization.
  * Updated translations.
  * Update French translation
  * Disabled noinst data.
* Tue Jun 26 2012 tiwai@suse.de
- back to version 1.2.7, as 1.4rc is still too unstable and
  doesn't work on M17N/12.1 systems at all
* Sat Jun  9 2012 hillwood@linuxfans.org
- update to 1.3.99.20120327(1.4rc).
* Thu Jun  7 2012 hillwood@linuxfans.org
- update to 1.2.7
* Fri Jul 22 2011 tiwai@suse.de
- Add missing locale-specific provides tag (bnc#707712)
* Tue Jun 14 2011 swyear@gmail.com
- Update to 1.2.6
  translation updates; gconf-SEGV fix; fixes for new ibus; etc
* Wed Mar 24 2010 tiwai@suse.de
- fix file list
* Thu Jan 28 2010 mxwu@novell.com
- Initial import
